aboutsummaryrefslogtreecommitdiffstats
path: root/LUFA/Drivers/USB/HighLevel/StdDescriptors.h
diff options
context:
space:
mode:
Diffstat (limited to 'LUFA/Drivers/USB/HighLevel/StdDescriptors.h')
-rw-r--r--LUFA/Drivers/USB/HighLevel/StdDescriptors.h44
1 files changed, 22 insertions, 22 deletions
diff --git a/LUFA/Drivers/USB/HighLevel/StdDescriptors.h b/LUFA/Drivers/USB/HighLevel/StdDescriptors.h
index 431080b72..caa0fb046 100644
--- a/LUFA/Drivers/USB/HighLevel/StdDescriptors.h
+++ b/LUFA/Drivers/USB/HighLevel/StdDescriptors.h
@@ -90,85 +90,85 @@
#define VERSION_BCD(x) ((((VERSION_TENS(x) << 4) | VERSION_ONES(x)) << 8) | \
((VERSION_TENTHS(x) << 4) | VERSION_HUNDREDTHS(x)))
/** String language ID for the English language. Should be used in USB_Descriptor_Language_t descriptors
* to indicate that the English language is supported by the device in its string descriptors.
*/
#define LANGUAGE_ID_ENG 0x0409
/** Can be masked with an endpoint address for a USB_Descriptor_Endpoint_t endpoint descriptor's
* EndpointAddress value to indicate to the host that the endpoint is of the IN direction (i.e, from
* device to host).
*/
#define ENDPOINT_DESCRIPTOR_DIR_IN 0x80
/** Can be masked with an endpoint address for a USB_Descriptor_Endpoint_t endpoint descriptor's
* EndpointAddress value to indicate to the host that the endpoint is of the OUT direction (i.e, from
* host to device).
*/
#define ENDPOINT_DESCRIPTOR_DIR_OUT 0x00
/** Can be masked with other configuration descriptor attributes for a USB_Descriptor_Configuration_Header_t
* descriptor's ConfigAttributes value to indicate that the specified configuration can draw its power
* from the host's VBUS line.
*/
#define USB_CONFIG_ATTR_BUSPOWERED 0x80
/** Can be masked with other configuration descriptor attributes for a USB_Descriptor_Configuration_Header_t
* descriptor's ConfigAttributes value to indicate that the specified configuration can draw its power
* from the device's own power source.
*/
#define USB_CONFIG_ATTR_SELFPOWERED 0xC0
/** Can be masked with other configuration descriptor attributes for a USB_Descriptor_Configuration_Header_t
* descriptor's ConfigAttributes value to indicate that the specified configuration supports the
* remote wakeup feature of the USB standard, allowing a suspended USB device to wake up the host upon
* request.
*/
#define USB_CONFIG_ATTR_REMOTEWAKEUP 0xA0
/** Can be masked with other endpoint descriptor attributes for a USB_Descriptor_Endpoint_t descriptor's
* Attributes value to indicate that the specified endpoint is not synchronized.
*
* \see The USB specification for more details on the possible Endpoint attributes.
*/
#define ENDPOINT_ATTR_NO_SYNC (0 << 2)
/** Can be masked with other endpoint descriptor attributes for a USB_Descriptor_Endpoint_t descriptor's
* Attributes value to indicate that the specified endpoint is asynchronous.
*
* \see The USB specification for more details on the possible Endpoint attributes.
*/
#define ENDPOINT_ATTR_ASYNC (1 << 2)
/** Can be masked with other endpoint descriptor attributes for a USB_Descriptor_Endpoint_t descriptor's
* Attributes value to indicate that the specified endpoint is adaptive.
*
* \see The USB specification for more details on the possible Endpoint attributes.
*/
#define ENDPOINT_ATTR_ADAPTIVE (2 << 2)
/** Can be masked with other endpoint descriptor attributes for a USB_Descriptor_Endpoint_t descriptor's
* Attributes value to indicate that the specified endpoint is synchronized.
*
* \see The USB specification for more details on the possible Endpoint attributes.
*/
#define ENDPOINT_ATTR_SYNC (3 << 2)
/** Can be masked with other endpoint descriptor attributes for a USB_Descriptor_Endpoint_t descriptor's
* Attributes value to indicate that the specified endpoint is used for data transfers.
*
* \see The USB specification for more details on the possible Endpoint usage attributes.
*/
#define ENDPOINT_USAGE_DATA (0 << 4)
/** Can be masked with other endpoint descriptor attributes for a USB_Descriptor_Endpoint_t descriptor's
* Attributes value to indicate that the specified endpoint is used for feedback.
*
* \see The USB specification for more details on the possible Endpoint usage attributes.
*/
#define ENDPOINT_USAGE_FEEDBACK (1 << 4)
/** Can be masked with other endpoint descriptor attributes for a USB_Descriptor_Endpoint_t descriptor's
* Attributes value to indicate that the specified endpoint is used for implicit feedback.
*
* \see The USB specification for more details on the possible Endpoint usage attributes.
@@ -180,7 +180,7 @@
/* Events: */
#if defined(USB_CAN_BE_DEVICE) || defined(__DOXYGEN__)
/** This module raises the Device Error event while in device mode, if the USB_GetDescriptor()
* routine is not hooked in the user application to properly return descriptors to the library.
*
* \see Events.h for more information on this event.
@@ -215,7 +215,7 @@
{
#if defined(USE_NONSTANDARD_DESCRIPTOR_NAMES) || defined(__DOXYGEN__)
uint8_t Size; /**< Size of the descriptor, in bytes. */
- uint8_t Type; /**< Type of the descriptor, either a value in DescriptorTypes_t or a value
+ uint8_t Type; /**< Type of the descriptor, either a value in \ref USB_DescriptorTypes_t or a value
* given by the specific class.
*/
#else
@@ -251,7 +251,7 @@
* host will request this string via a separate
* control request for the string descriptor.
*
* \note If no string supplied, use NO_DESCRIPTOR.
*/
uint8_t ProductStrIndex; /**< String index for the product name/details.
*
@@ -309,7 +309,7 @@
*/
uint8_t MaxPowerConsumption; /**< Maximum power consumption of the device while in the
* current configuration, calculated by the USB_CONFIG_POWER_MA()
* macro.
*/
#else
@@ -364,7 +364,7 @@
#endif
} USB_Descriptor_Interface_t;
- /** Type define for a standard interface association descriptor.
+ /** Type define for a standard Interface Association descriptor.
*
* This descriptor has been added as a supplement to the USB2.0 standard, in the ECN located at
* <a>http://www.usb.org/developers/docs/InterfaceAssociationDescriptor_ecn.pdf</a>. It allows compound
@@ -442,7 +442,7 @@
} USB_Descriptor_Endpoint_t;
/** Type define for a standard string descriptor. Unlike other standard descriptors, the length
* of the descriptor for placement in the descriptor header must be determined by the USB_STRING_LEN()
* macro rather than by the size of the descriptor structure, as the length is not fixed.
*
* This structure should also be used for string index 0, which contains the supported language IDs for
@@ -479,7 +479,7 @@
/* Function Prototypes: */
/** Function to retrieve a given descriptor's size and memory location from the given descriptor type value,
* index and language ID. This function MUST be overridden in the user application (added with full, identical
* prototype and name except for the ATTR_WEAK attribute) so that the library can call it to retrieve descriptor
* data.
*
* \param wValue The type of the descriptor to retrieve in the upper byte, and the index in the
@@ -490,7 +490,7 @@
* otherwise zero for standard descriptors, or as defined in a class-specific
* standards.
* \param DescriptorAddress Pointer to the descriptor in memory. This should be set by the routine to
* the location of the descriptor, found by the DESCRIPTOR_ADDRESS macro.
*
* \note By default, the library expects all descriptors to be located in flash memory via the PROGMEM attribute.
* If descriptors should be located in RAM or EEPROM instead (to speed up access in the case of RAM, or to
@@ -498,7 +498,7 @@
* USE_EEPROM_DESCRIPTORS tokens may be defined in the project makefile and passed to the compiler by the -D
* switch.
*
* \return Size in bytes of the descriptor if it exists, zero or NO_DESCRIPTOR otherwise
*/
uint16_t USB_GetDescriptor(const uint16_t wValue, const uint8_t wIndex, void** const DescriptorAddress)
ATTR_WARN_UNUSED_RESULT ATTR_WEAK ATTR_NON_NULL_PTR_ARG(3);
@@ -90,85 +90,85 @@
#define VERSION_BCD(x) ((((VERSION_TENS(x) << 4) | VERSION_ONES(x)) << 8) | \
((VERSION_TENTHS(x) << 4) | VERSION_HUNDREDTHS(x)))
- /** String language ID for the English language. Should be used in USB_Descriptor_Language_t descriptors
+ /** String language ID for the English language. Should be used in \ref USB_Descriptor_String_t descriptors
* to indicate that the English language is supported by the device in its string descriptors.
*/
@@ -90,85 +90,85 @@
*/
#define LANGUAGE_ID_ENG 0x0409
- /** Can be masked with an endpoint address for a USB_Descriptor_Endpoint_t endpoint descriptor's
+ /** Can be masked with an endpoint address for a \ref USB_Descriptor_Endpoint_t endpoint descriptor's
* EndpointAddress value to indicate to the host that the endpoint is of the IN direction (i.e, from
* device to host).
@@ -90,85 +90,85 @@
*/
#define ENDPOINT_DESCRIPTOR_DIR_IN 0x80
- /** Can be masked with an endpoint address for a USB_Descriptor_Endpoint_t endpoint descriptor's
+ /** Can be masked with an endpoint address for a \ref USB_Descriptor_Endpoint_t endpoint descriptor's
* EndpointAddress value to indicate to the host that the endpoint is of the OUT direction (i.e, from
* host to device).
@@ -90,85 +90,85 @@
*/
#define ENDPOINT_DESCRIPTOR_DIR_OUT 0x00
- /** Can be masked with other configuration descriptor attributes for a USB_Descriptor_Configuration_Header_t
+ /** Can be masked with other configuration descriptor attributes for a \ref USB_Descriptor_Configuration_Header_t
* descriptor's ConfigAttributes value to indicate that the specified configuration can draw its power
* from the host's VBUS line.
@@ -90,85 +90,85 @@
*/
#define USB_CONFIG_ATTR_BUSPOWERED 0x80
- /** Can be masked with other configuration descriptor attributes for a USB_Descriptor_Configuration_Header_t
+ /** Can be masked with other configuration descriptor attributes for a \ref USB_Descriptor_Configuration_Header_t
* descriptor's ConfigAttributes value to indicate that the specified configuration can draw its power
* from the device's own power source.
@@ -90,85 +90,85 @@
*/
#define USB_CONFIG_ATTR_SELFPOWERED 0xC0
- /** Can be masked with other configuration descriptor attributes for a USB_Descriptor_Configuration_Header_t
+ /** Can be masked with other configuration descriptor attributes for a \ref USB_Descriptor_Configuration_Header_t
* descriptor's ConfigAttributes value to indicate that the specified configuration supports the
* remote wakeup feature of the USB standard, allowing a suspended USB device to wake up the host upon
@@ -90,85 +90,85 @@
*/
#define USB_CONFIG_ATTR_REMOTEWAKEUP 0xA0
- /** Can be masked with other endpoint descriptor attributes for a USB_Descriptor_Endpoint_t descriptor's
+ /** Can be masked with other endpoint descriptor attributes for a \ref USB_Descriptor_Endpoint_t descriptor's
* Attributes value to indicate that the specified endpoint is not synchronized.
*
@@ -90,85 +90,85 @@
*/
#define ENDPOINT_ATTR_NO_SYNC (0 << 2)
- /** Can be masked with other endpoint descriptor attributes for a USB_Descriptor_Endpoint_t descriptor's
+ /** Can be masked with other endpoint descriptor attributes for a \ref USB_Descriptor_Endpoint_t descriptor's
* Attributes value to indicate that the specified endpoint is asynchronous.
*
@@ -90,85 +90,85 @@
*/
#define ENDPOINT_ATTR_ASYNC (1 << 2)
- /** Can be masked with other endpoint descriptor attributes for a USB_Descriptor_Endpoint_t descriptor's
+ /** Can be masked with other endpoint descriptor attributes for a \ref USB_Descriptor_Endpoint_t descriptor's
* Attributes value to indicate that the specified endpoint is adaptive.
*
@@ -90,85 +90,85 @@
*/
#define ENDPOINT_ATTR_ADAPTIVE (2 << 2)
- /** Can be masked with other endpoint descriptor attributes for a USB_Descriptor_Endpoint_t descriptor's
+ /** Can be masked with other endpoint descriptor attributes for a \ref USB_Descriptor_Endpoint_t descriptor's
* Attributes value to indicate that the specified endpoint is synchronized.
*
@@ -90,85 +90,85 @@
*/
#define ENDPOINT_ATTR_SYNC (3 << 2)
- /** Can be masked with other endpoint descriptor attributes for a USB_Descriptor_Endpoint_t descriptor's
+ /** Can be masked with other endpoint descriptor attributes for a \ref USB_Descriptor_Endpoint_t descriptor's
* Attributes value to indicate that the specified endpoint is used for data transfers.
*
@@ -90,85 +90,85 @@
*/
#define ENDPOINT_USAGE_DATA (0 << 4)
- /** Can be masked with other endpoint descriptor attributes for a USB_Descriptor_Endpoint_t descriptor's
+ /** Can be masked with other endpoint descriptor attributes for a \ref USB_Descriptor_Endpoint_t descriptor's
* Attributes value to indicate that the specified endpoint is used for feedback.
*
@@ -90,85 +90,85 @@
*/
#define ENDPOINT_USAGE_FEEDBACK (1 << 4)
- /** Can be masked with other endpoint descriptor attributes for a USB_Descriptor_Endpoint_t descriptor's
+ /** Can be masked with other endpoint descriptor attributes for a \ref USB_Descriptor_Endpoint_t descriptor's
* Attributes value to indicate that the specified endpoint is used for implicit feedback.
*
@@ -180,7 +180,7 @@
/* Events: */
#if defined(USB_CAN_BE_DEVICE) || defined(__DOXYGEN__)
- /** This module raises the Device Error event while in device mode, if the USB_GetDescriptor()
+ /** This module raises the Device Error event while in device mode, if the \ref USB_GetDescriptor()
* routine is not hooked in the user application to properly return descriptors to the library.
*
@@ -251,7 +251,7 @@
* control request for the string descriptor.
*
- * \note If no string supplied, use NO_DESCRIPTOR.
+ * \note If no string supplied, use \ref NO_DESCRIPTOR.
*/
uint8_t ProductStrIndex; /**< String index for the product name/details.
@@ -309,7 +309,7 @@
*/
uint8_t MaxPowerConsumption; /**< Maximum power consumption of the device while in the
- * current configuration, calculated by the USB_CONFIG_POWER_MA()
+ * current configuration, calculated by the \ref USB_CONFIG_POWER_MA()
* macro.
*/
@@ -442,7 +442,7 @@
} USB_Descriptor_Endpoint_t;
/** Type define for a standard string descriptor. Unlike other standard descriptors, the length
- * of the descriptor for placement in the descriptor header must be determined by the USB_STRING_LEN()
+ * of the descriptor for placement in the descriptor header must be determined by the \ref USB_STRING_LEN()
* macro rather than by the size of the descriptor structure, as the length is not fixed.
*
@@ -479,7 +479,7 @@
/** Function to retrieve a given descriptor's size and memory location from the given descriptor type value,
* index and language ID. This function MUST be overridden in the user application (added with full, identical
- * prototype and name except for the ATTR_WEAK attribute) so that the library can call it to retrieve descriptor
+ * prototype and name except for the \ref ATTR_WEAK attribute) so that the library can call it to retrieve descriptor
* data.
*
@@ -490,7 +490,7 @@
* standards.
* \param DescriptorAddress Pointer to the descriptor in memory. This should be set by the routine to
- * the location of the descriptor, found by the DESCRIPTOR_ADDRESS macro.
+ * the location of the descriptor, found by the \ref DESCRIPTOR_ADDRESS() macro.
*
* \note By default, the library expects all descriptors to be located in flash memory via the PROGMEM attribute.
@@ -498,7 +498,7 @@
* switch.
*
- * \return Size in bytes of the descriptor if it exists, zero or NO_DESCRIPTOR otherwise
+ * \return Size in bytes of the descriptor if it exists, zero or \ref NO_DESCRIPTOR otherwise
*/
uint16_t USB_GetDescriptor(const uint16_t wValue, const uint8_t wIndex, void** const DescriptorAddress)